package
Version:
v0.0.0-...-76ada3d
Opens a new window with list of versions in this module.
Published: Jan 1, 2026
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
- Variables
-
func Help()
-
func Monitor(path string, hasChanged chan bool)
-
func Start(dir, ext, name, username, password string, extension, network, realtime bool, ...)
-
func StartWebsocket(dir string, port uint16)
func Start(dir, ext, name, username, password string, extension, network, realtime bool, port uint16)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.